@@ -104,7 +104,7 @@ except ImportError:
                 " install ordereddict 1.1 from pypi for python2.6")
 
 __pkgname__ = 'python-crontab'
-__version__ = '2.2.1'
+__version__ = '2.2.2'
 
 ITEMREX = re.compile(r'^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)'
                      r'\s+([^@#\s]+)\s+([^#\n]*)(\s+#\s*([^\n]*)|$)')
@@ -287,7 +287,12 @@ class CronTab(object):
         elif '=' in line:
             if ' ' not in line or line.index('=') < line.index(' '):
                 (name, value) = line.split('=', 1)
-                self._parked_env[name.strip()] = value.strip()
+                value = value.strip()
+                for quot in "\"'":
+                    if value[0] == quot and value[-1] == quot:
+                        value = value.strip(quot)
+                        break
+                self._parked_env[name.strip()] = value
                 return None
 
         elif not self.crons and self._parked_env:
@@ -379,13 +384,19 @@ class CronTab(object):
     def find_command(self, command):
         """Return an iter of jobs matching any part of the command."""
         for job in list(self.crons):
-            if command in job.command:
+            if isinstance(command, re._pattern_type):
+                if command.findall(job.command):
+                    yield job
+            elif command in job.command:
                 yield job
 
     def find_comment(self, comment):
         """Return an iter of jobs that match the comment field exactly."""
         for job in list(self.crons):
-            if job.comment == comment:
+            if isinstance(comment, re._pattern_type):
+                if comment.findall(job.comment):
+                    yield job
+            elif comment == job.comment:
                 yield job
 
     def find_time(self, *args):
@@ -1269,6 +1280,8 @@ class OrderedVariableList(OrderedDict):
             if self.previous:
                 if self.previous.all().get(key, None) == value:
                     continue
+            if ' ' in unicode(value):
+                value = '"%s"' % value
             ret.append("%s=%s" % (key, unicode(value)))
         ret.append('')
         return "\n".join(ret)
